conductor-go

module
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2023 License: Apache-2.0

README

Netflix Conductor Go SDK

The conductor-go repository provides the client SDKs to build task workers in Go.

Building the task workers in Go mainly consists of the following steps:

  1. Setup conductor-go package
  2. Create and run task workers
  3. Create workflows using code
  4. API Documentation
Setup Conductor Go Package​
  • Create a folder to build your package
mkdir quickstart/
cd quickstart/
go mod init quickstart
  • Get Conductor Go SDK
go get github.com/conductor-sdk/conductor-go

Configurations

Authentication Settings (Optional)

Configure the authentication settings if your Conductor server requires authentication.

  • keyId: Key for authentication.
  • keySecret: Secret for the key.
authenticationSettings := settings.NewAuthenticationSettings(
  "keyId",
  "keySecret",
)
Access Control Setup

See Access Control for more details on role-based access control with Conductor and generating API keys for your environment.

Configure API Client

apiClient := client.NewAPIClient(
    settings.NewAuthenticationSettings(
        KEY,
        SECRET,
    ),
    settings.NewHttpSettings(
        "https://play.orkes.io",
    ),
)
	
Setup Logging

SDK uses logrus for logging.

func init() {
	log.SetFormatter(&log.TextFormatter{})
	log.SetOutput(os.Stdout)
	log.SetLevel(log.DebugLevel)
}
Next: Create and run task workers

Directories

Path Synopsis
sdk
client
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License.

Jump to